/*!
 * Copyright 2014 Smart Parking. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*!
 * @module smartcloud
 */

'use strict';

/**
 * @type {module:smartcloud/errors}
 * @private
 */
var Errors = require('./errors.js');

/**
 * SmartCloud is a utility helper for interacting with the Smartcloud and GCP platforms
 *
 * @constructor
 *
 * @example
 * const SC = new SmartCloud(options)
 *
 * @param {object} options - Configuration object containing the following properties:

 */
function SmartCloud( options ) {
  if (!(this instanceof SmartCloud)) {
    return new SmartCloud(options);
  }
  this.options = options;
  this.common;
}

// constructor wrappers

SmartCloud.prototype.SmartFunction = function( options ) {
  return require('./smartfunction.js')(options);
};

SmartCloud.prototype.PubSub = function( options ) {
  return require('./pubsub.js')(options);
};

SmartCloud.prototype.Datastore = function( options ) {
  return require('./datastore.js')(options);
};

SmartCloud.prototype.BigTable = function( options ) {
  return require('./bigtable.js')(options);
};

SmartCloud.prototype.Setup = function( app, options ) {
  return require('./setup.js')(app, options);
};

SmartCloud.prototype.Deploy = function( app, options ) {
  return require('./deploy.js')(app, options);
};

SmartCloud.prototype.OpenLocation = function( options ) {
  return require('./openlocation.js')(options);
};

SmartCloud.prototype.Common = function( options ) {
  if(!this.common) this.common = require('./common.js')(options);
  return this.common;
};

// utility wrappers
SmartCloud.prototype.getUUID = function() {
  return this.Common().getUUID();
};

SmartCloud.prototype.hash = function(stringToHash) {
  return this.Common().hash(stringToHash);
};

SmartCloud.prototype.getReference = function(json) {
  return this.Common().getReference(json);
};

module.exports = SmartCloud;
