/*!
 * Copyright 2014 Smart Parking. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*!
 * @module smartcloud/smartlog
 */

'use strict';

/**
 * SmartCloud Log Message is a normalized message to help with Stackdriver
 * filtering based on the Fact base object
 *
 * @constructor
 *
 * @example
 * console.error(new SmartLog(obj, message))
 */
function SmartLog( sender, obj, message, isError ) {
  if(!obj) { obj = { fact: {} } }
  if(message instanceof Error) message = message.name +": "+ message.message;
  const factType = obj.fact ? obj.fact.factType : obj.factType;
  const factSubtype = obj.fact ? obj.fact.factSubtype : obj.factSubtype;

  return {
    logType : 'SmartLog',
    sender: sender,
    isError : isError || false,
    factType : factType || 'Unknown',
    factSubtype : factSubtype || 'Unknown',
    message : message,
    fact : obj
  };
}

module.exports = SmartLog;
